from distutils.core import setup

setup(
    name        = 'rayle',
    version     = '1.0.1',
    py_modules  = ['rayle'],
    author      = 'rayle',
    author_email    = 'a@a.com',
    url             = '',
    description     = '',
    )
